==> resin-4.0.27-src.tar.gz: resin-4.0.27/modules/resin/src/com/caucho/amqp/marshal/AmqpStringEncoder.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amqp.marshal;

import java.io.IOException;

import com.caucho.amqp.io.AmqpConstants;
import com.caucho.amqp.io.AmqpWriter;


/**
 * Encodes a message as a string.
 */
public class AmqpStringEncoder extends AbstractMessageEncoder<String>
  implements AmqpMessageEncoder<String>
{
  public static final AmqpStringEncoder ENCODER = new AmqpStringEncoder();
  
  @Override
  public String getContentType(String value)
  {
    return "text/plain";
  }
  
  @Override
  public void encode(AmqpWriter out, String value)
    throws IOException
  {
    out.writeDescriptor(AmqpConstants.ST_MESSAGE_VALUE);
    out.writeString(value);
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/amqp/marshal/AmqpStringEncoder.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amqp.marshal;

import java.io.IOException;

import com.caucho.amqp.io.AmqpConstants;
import com.caucho.amqp.io.AmqpWriter;


/**
 * Encodes a message as a string.
 */
public class AmqpStringEncoder extends AbstractMessageEncoder<String>
  implements AmqpMessageEncoder<String>
{
  public static final AmqpStringEncoder ENCODER = new AmqpStringEncoder();
  
  @Override
  public String getContentType(String value)
  {
    return "text/plain";
  }
  
  @Override
  public void encodeData(AmqpWriter out, String value)
    throws IOException
  {
    out.writeDescriptor(AmqpConstants.ST_MESSAGE_VALUE);
    out.writeString(value);
  }
}
